Learn R Programming

wrTopDownFrag (version 1.0.4)

AAfragSettings: Settings For AA Fragmentation

Description

This function provides basic settings for what types of fragments may accomodate which type of modifications : $knownMods: information about which modifications may be considered, $specAAMod: specifc AA sites (if applicable), $specAAMod: specifc AA sites (if applicable). For example, here 'p' codes for gain of mass for HPO3 only at S, T and Y residues. Note: $knownMods$Nterm and $knownMods$Cterm are treated as mutually exclusive

Usage

AAfragSettings(outTy = "all", silent = FALSE, debug = FALSE, callFrom = NULL)

Value

This function returns a list ($knownMods, $knspecAAMods, $modChem, $neutralLossOrGain)

Arguments

outTy

(character) default "all" or any of the list-elements

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allows easier tracking of messages produced

See Also

makeFragments, fragmentSeq, massDeFormula

Examples

Run this code
AAfragSettings()

Run the code above in your browser using DataLab